@@ -26,5 +26,8 @@ class UIFrameworkActService(object):
     def sendNewOrderSingle(self, request, timeout=None):
         return self.connector.create_request('sendNewOrderSingle', request, timeout)
 
-    def extractOrderDetails(self, request, timeout=None):
-        return self.connector.create_request('extractOrderDetails', request, timeout)
+    def extractLastOrderDetails(self, request, timeout=None):
+        return self.connector.create_request('extractLastOrderDetails', request, timeout)
+
+    def extractLastSystemMessage(self, request, timeout=None):
+        return self.connector.create_request('extractLastSystemMessage', request, timeout)
